@@ -6,6 +6,7 @@ import requests
 from django.conf import settings
 from django.contrib.staticfiles.finders import find
 # noinspection PyProtectedMember
+from django.core.exceptions import ImproperlyConfigured
 from django.template import Library
 from django.utils.html import format_html
 
@@ -18,17 +19,24 @@ def get_static(icon_name):
     :param icon_name:
     :return: icon path
     """
-    custom_path = getattr(
+    custom_dir = getattr(
         settings,
         'BS_ICONS_CUSTOM_PATH',
         'custom-icons'
     )
+
     if settings.DEBUG:
-        return os.path.join(
-            find(custom_path), '.'.join((icon_name, 'svg'))
-        )
+        custom_path = find(custom_dir)
+        if not custom_path:
+            raise ImproperlyConfigured("BS_ICONS_CUSTOM_PATH does not exist.")
+    else:
+        custom_path = os.path.join(settings.STATIC_ROOT, custom_dir)
+
+    if not os.path.exists(custom_path):
+        raise ImproperlyConfigured("BS_ICONS_CUSTOM_PATH does not exist.")
+
     return os.path.join(
-        settings.STATIC_ROOT, custom_path, '.'.join((icon_name, 'svg'))
+        custom_path, '.'.join((icon_name, 'svg'))
     )
 
 
@@ -104,7 +112,8 @@ def icon(icon_path, icon_name, size=None, color=None, extra_classes=None):
         cache_file = os.path.join(cache_path, cache_name)
         if os.path.exists(cache_file):
             # icon exists in cache, use that
-            return open(cache_file, 'r').read()
+            with open(cache_file, 'r') as icon_file:
+                return icon_file.read()
 
     # cached icon doesn't exist or no cache configured, create and return icon
     try:
@@ -120,7 +129,8 @@ def icon(icon_path, icon_name, size=None, color=None, extra_classes=None):
         svg = render_svg(content, size, color, extra_classes)
         # if cache configured write icon to cache
         if cache_path and cache_file:
-            open(cache_file, 'w').write(svg)
+            with open(cache_file, 'w') as icon_file:
+                icon_file.write(svg)
     except requests.ConnectionError:
         return getattr(
             settings,
